Python Interface
================

* :ref:`python/interface:classes`

  * :ref:`python/interface:options`
  * :ref:`python/interface:termmanager`
  * :ref:`python/interface:bitwuzla`
  * :ref:`python/interface:sort`
  * :ref:`python/interface:term`
  * :ref:`python/interface:optioninfo`

* :ref:`python/interface:enums`

  * :ref:`python/interface:option`
  * :ref:`python/interface:optioninfokind`
  * :ref:`python/interface:kind`
  * :ref:`python/interface:result`
  * :ref:`python/interface:roundingmode`


Classes
-------

Options
^^^^^^^
.. autoclass:: bitwuzla.Options
   :members:
   :undoc-members:

TermManager
^^^^^^^^^^^
.. autoclass:: bitwuzla.TermManager
   :members:
   :undoc-members:

   .. automethod:: __init__

Bitwuzla
^^^^^^^^
.. autoclass:: bitwuzla.Bitwuzla
   :members:
   :undoc-members:

   .. automethod:: __init__

Sort
^^^^
.. autoclass:: bitwuzla.Sort
   :members:
   :undoc-members:

Term
^^^^
.. autoclass:: bitwuzla.Term
   :members:
   :undoc-members:

Parser
^^^^^^
.. autoclass:: bitwuzla.Parser
   :members:
   :undoc-members:

   .. automethod:: __init__

OptionInfo
^^^^^^^^^^
.. autoclass:: bitwuzla.OptionInfo
   :members:
   :undoc-members:

Enums
------

Option
^^^^^^
.. autoclass:: bitwuzla.Option
   :members:
   :undoc-members:

OptionInfoKind
^^^^^^^^^^^^^^
.. autoclass:: bitwuzla.OptionInfoKind
   :members:
   :undoc-members:

Kind
^^^^
.. autoclass:: bitwuzla.Kind
   :members:
   :undoc-members:

Result
^^^^^^
.. autoclass:: bitwuzla.Result
   :members:
   :undoc-members:

RoundingMode
^^^^^^^^^^^^
.. autoclass:: bitwuzla.RoundingMode
   :members:
   :undoc-members:


